@@ -3,13 +3,13 @@ BEGIN {
   $Dist::Zilla::PluginBundle::Author::GETTY::AUTHORITY = 'cpan:GETTY';
 }
 {
-  $Dist::Zilla::PluginBundle::Author::GETTY::VERSION = '0.003';
+  $Dist::Zilla::PluginBundle::Author::GETTY::VERSION = '0.004';
 }
 # ABSTRACT: BeLike::GETTY when you build your dists
 
 use Moose;
 use Moose::Autobox;
-use Dist::Zilla 2.100922; # TestRelease
+use Dist::Zilla;
 with 'Dist::Zilla::Role::PluginBundle::Easy';
 
 
@@ -30,6 +30,20 @@ has major_version => (
   default => sub { $_[0]->payload->{version} || 0 },
 );
 
+has author => (
+  is      => 'ro',
+  isa     => 'Str',
+  lazy    => 1,
+  default => sub { 'GETTY' },
+);
+
+has release_branch => (
+  is      => 'ro',
+  isa     => 'Str',
+  lazy    => 1,
+  default => sub { 'master' },
+);
+
 has is_task => (
   is      => 'ro',
   isa     => 'Bool',
@@ -89,14 +103,14 @@ sub configure {
 
 	$self->add_plugins([
 		'Authority' => {
-			authority => 'cpan:GETTY',
+			authority => 'cpan:'.$self->author,
 			do_metadata => 1,
 		}
 	]);
 
   $self->add_plugins([
     'Git::CheckFor::CorrectBranch' => {
-      release_branch => 'master',
+      release_branch => $self->release_branch,
     },
   ]);
 
@@ -145,7 +159,7 @@ Dist::Zilla::PluginBundle::Author::GETTY - BeLike::GETTY when you build your dis
 
 =head1 VERSION
 
-version 0.003
+version 0.004
 
 =head1 DESCRIPTION
 
@@ -186,9 +200,24 @@ This is the plugin bundle that GETTY uses.  It is equivalent to:
   wrap_column = 74
   debug = 0
 
+You can configure it (given values are default):
+
+  [@Author::GETTY]
+  author = GETTY
+  release_branch = master
+  weaver_config = @Author::GETTY
+
 If the C<task> argument is given to the bundle, PodWeaver is replaced with
-TaskWeaver and Git::NextVersion is replaced with AutoVersion.  If the
-C<manual_version> argument is given, AutoVersion is omitted. 
+TaskWeaver and Git::NextVersion is replaced with AutoVersion:
+
+  [@Author::GETTY]
+  task = 1
+
+If the C<manual_version> argument is given, AutoVersion and Git::NextVersion
+are omitted.
+
+  [@Author::GETTY]
+  manual_version = 1.222333
 
 =head1 AUTHOR
 
